==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/BuildOutputBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildOutputBuilder extends BuildOutputFluentImpl<BuildOutputBuilder> implements VisitableBuilder<BuildOutput,BuildOutputBuilder>{
  public BuildOutputBuilder() {
    this(false);
  }
  public BuildOutputBuilder(Boolean validationEnabled) {
    this(new BuildOutput(), validationEnabled);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildOutput(), validationEnabled);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,BuildOutput instance) {
    this(fluent, instance, false);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,BuildOutput instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withImageLabels(instance.getImageLabels());
      fluent.withPushSecret(instance.getPushSecret());
      fluent.withTo(instance.getTo());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BuildOutputBuilder(BuildOutput instance) {
    this(instance,false);
  }
  public BuildOutputBuilder(BuildOutput instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withImageLabels(instance.getImageLabels());
      this.withPushSecret(instance.getPushSecret());
      this.withTo(instance.getTo());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  BuildOutputFluent<?> fluent;
  Boolean validationEnabled;
  public BuildOutput build() {
    BuildOutput buildable = new BuildOutput(fluent.getImageLabels(),fluent.getPushSecret(),fluent.getTo());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/BuildOutputBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class BuildOutputBuilder extends BuildOutputFluent<BuildOutputBuilder> implements VisitableBuilder<BuildOutput,BuildOutputBuilder>{
  public BuildOutputBuilder() {
    this(false);
  }
  public BuildOutputBuilder(Boolean validationEnabled) {
    this(new BuildOutput(), validationEnabled);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent) {
    this(fluent, false);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new BuildOutput(), validationEnabled);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,BuildOutput instance) {
    this(fluent, instance, false);
  }
  public BuildOutputBuilder(BuildOutputFluent<?> fluent,BuildOutput instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new BuildOutput());

    if (instance != null) {
      fluent.withImageLabels(instance.getImageLabels());
      fluent.withPushSecret(instance.getPushSecret());
      fluent.withTo(instance.getTo());
      fluent.withImageLabels(instance.getImageLabels());
      fluent.withPushSecret(instance.getPushSecret());
      fluent.withTo(instance.getTo());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public BuildOutputBuilder(BuildOutput instance) {
    this(instance,false);
  }
  public BuildOutputBuilder(BuildOutput instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new BuildOutput());

    if (instance != null) {
      this.withImageLabels(instance.getImageLabels());
      this.withPushSecret(instance.getPushSecret());
      this.withTo(instance.getTo());
      this.withImageLabels(instance.getImageLabels());
      this.withPushSecret(instance.getPushSecret());
      this.withTo(instance.getTo());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  BuildOutputFluent<?> fluent;
  Boolean validationEnabled;
  public BuildOutput build() {
    BuildOutput buildable = new BuildOutput(fluent.buildImageLabels(),fluent.buildPushSecret(),fluent.buildTo());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
